@@ -1,7 +1,8 @@
-# Copyright (C) 2014 Jurriaan Bremer.
+# Copyright (C) 2014-2015 Jurriaan Bremer.
 # This file is part of VMCloak - http://www.vmcloak.org/.
 # See the file 'docs/LICENSE.txt' for copying permission.
 
+from __future__ import absolute_import
 import argparse
 import hashlib
 import json
@@ -194,11 +195,11 @@ def read_bird(name):
     return read_birds().get(name)
 
 
-def add_bird(name, hdd_path):
+def add_bird(name, vmtype, hdd_path):
     path = os.path.join(os.getenv('HOME'), '.vmcloak', 'birds.json')
 
     birds = read_birds()
-    birds[name] = dict(hdd_path=hdd_path)
+    birds[name] = dict(vmtype=vmtype, hdd_path=hdd_path)
 
     open(path, 'wb').write(json.dumps(birds))
 
@@ -210,8 +211,6 @@ def shared_parameters():
     parser.add_argument('--vm-dir', type=str, help='Base directory for the virtual machine and its associated files.')
     parser.add_argument('--data-dir', type=str, help='Base directory for the virtual machine harddisks and images.')
     parser.add_argument('--vm', type=str, help='Virtual Machine Software (VirtualBox.)')
-    parser.add_argument('--vboxrpc-url', type=str, help='URL to VBoxRPC instance.')
-    parser.add_argument('--vboxrpc-auth', type=str, help='Credentials to VBoxRPC instance.')
     parser.add_argument('--ramsize', help='Available virtual memory (in MB) for this virtual machine.')
     parser.add_argument('--resolution', type=str, help='Virtual Machine resolution.')
     parser.add_argument('--hdsize', help='Maximum size (in MB) of the dynamically allocated harddisk.')
@@ -221,6 +220,7 @@ def shared_parameters():
     parser.add_argument('--hostonly-mask', type=str, help='Static IP address mask to use on the Guest for the hostonly network.')
     parser.add_argument('--hostonly-gateway', type=str, help='Static IP address gateway to use on the Guest for the hostonly network.')
     parser.add_argument('--hostonly-macaddr', type=str, help='Mac address for the hostonly interface.')
+    parser.add_argument('--hostonly-adapter', type=str, help='Hostonly interface to use.')
     parser.add_argument('--bridged', type=str, help='Network interface for the bridged network.')
     parser.add_argument('--bridged-ip', type=str, help='Static IP address to use on the Guest for the bridged network.')
     parser.add_argument('--bridged-mask', type=str, help='Static IP address mask to use on the Guest for the bridged network.')
@@ -243,6 +243,7 @@ def shared_parameters():
     parser.add_argument('--temp-dirpath', type=str, help='Directory where to put temporary files.')
     parser.add_argument('--deps-directory', type=str, help='Dependency directory.')
     parser.add_argument('--deps-repository', type=str, help='Dependency repository.')
+    parser.add_argument('--run-executable', type=str, help='Extra executable to be ran after full initialization of the Virtual Machine.')
     parser.add_argument('-s', '--settings', type=str, default=[], action='append', help='Configuration file with various settings.')
     parser.add_argument('-r', '--recommended-settings', action='store_true', help='Use the recommended settings.')
     parser.add_argument('-u', '--user', type=str, help='Drop user privileges to this user')
@@ -250,8 +251,6 @@ def shared_parameters():
 
     defaults = dict(
         vm='virtualbox',
-        vboxrpc_url='http://localhost:9002/',
-        vboxrpc_auth='root:toor',
         cuckoo='',
         ramsize=1024,
         resolution='1024x768',
@@ -264,6 +263,7 @@ def shared_parameters():
         hostonly_ip='192.168.56.101',
         hostonly_mask='255.255.255.0',
         hostonly_gateway='192.168.56.1',
+        hostonly_adapter=None,
         bridged_mask='255.255.255.0',
         dns_server='8.8.8.8',
         tags='',
